@@ -1,4 +1,5 @@
 """Functions for converting coordinates."""
+from __future__ import annotations
 
 import astropy.units as u
 import numpy as np
@@ -9,11 +10,7 @@ from astropy.time import Time
 from copy import deepcopy
 from numpy import typing as npt
 from pyuvdata.uvbeam import UVBeam
-
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal
+from typing import Literal
 
 
 def enu_to_az_za(enu_e, enu_n, orientation="astropy", periodic_azimuth=True):
@@ -311,118 +308,3 @@ def prepare_beam(
         uvbeam_ = uvbeam
 
     return uvbeam_
-
-
-def uvbeam_to_lm(
-    uvbeam: UVBeam,
-    freqs: npt.ArrayLike,
-    n_pix_lm: int = 63,
-    polarized: bool = False,
-    use_feed: Literal["x", "y"] = "x",
-    **kwargs,
-):
-    """Evaluate a UVBeam object on a uniform direction cosine (l,m) grid.
-
-    Here, (l, m) are the direction cosines, associated with the East and North
-    ENU coordinates (and also the U and V directions for a zenith-pointing
-    drift-scan telescope). For a vector in East-North-Up (ENU) coordinates
-    vec{p}, we therefore have ``l = vec{p}.hat{e}`` etc.
-
-    N.B. This function does not perform any beam normalization.
-
-    Parameters
-    ----------
-    uvbeam : UVBeam object
-        Beam to convert to an (l, m) grid.
-    freqs : array_like
-        Frequencies to interpolate to in [Hz]. Shape=(NFREQS,).
-    n_pix_lm : int, optional
-        Number of pixels for each side of the beam grid.
-    polarized : bool, optional
-        Whether to return full polarized beam information or not.
-    use_feed
-        Which feed to use in the case of an *unpolarized* simulation (for a polarized
-        sim, it uses all available feeds).
-
-    Notes
-    -----
-    When ``polarized=True``, all combinations of axes and feeds are returned. In this
-    case, the input ``uvbeam`` must have a beam type of ``efield``, or else an error
-    is raised. Conversely, if ``polarized=False``, the convention is to return the
-    real-valued beam equal to the square root of the power beam of a linear polarization.
-    That is, either the sqrt of XX or YY. Needless to say, the desired feed must be
-    defined in the beam object. The input beam in this case can be in either 'efield'
-    or 'power' mode.
-
-    Returns
-    -------
-    ndarray
-        The beam map cube. Shape: (NFREQS, BEAM_PIX, BEAM_PIX) if
-        `polarized=False` or (NAXES, NFEEDS, NFREQS, BEAM_PIX, BEAM_PIX) if
-        `polarized=True`.
-    """
-    # Define angle cosines
-    L = bm_pix_to_lm(n_pix_lm)
-    L, m = np.meshgrid(L, L)
-    L = L.flatten()
-    m = m.flatten()
-
-    uvbeam = prepare_beam(uvbeam, polarized=polarized, use_feed=use_feed)
-
-    # Get azimuth and zenith angles (note the different azimuth convention
-    # used by UVBeam)
-    az, za = enu_to_az_za(enu_e=L, enu_n=m, orientation="uvbeam", periodic_azimuth=True)
-
-    # Interpolate beam onto cube
-    if polarized:
-        efield_beam = uvbeam.interp(
-            az_array=az, za_array=za, freq_array=freqs, **kwargs
-        )[0]
-        bm = efield_beam[:, 0, :, :, :]  # spw=0
-    else:
-        power_beam = uvbeam.interp(
-            az_array=az, za_array=za, freq_array=freqs, **kwargs
-        )[0]
-        bm = np.sqrt(power_beam[0, 0, 0, :, :])
-
-    # Reshape output
-    if polarized:
-        Naxes = bm.shape[0]  # polarization vector axes
-        Nfeeds = bm.shape[1]  # polarized feeds
-        return bm.reshape((Naxes, Nfeeds, len(freqs), n_pix_lm, n_pix_lm))
-    else:
-        return bm.reshape((len(freqs), n_pix_lm, n_pix_lm))
-
-
-def bm_pix_to_lm(bm_pix: int) -> np.ndarray:
-    """Return a sampling in projected coordinates.
-
-    This gives an array sampled from -1 to 1, with ``bm_pix`` points in it.
-    ``bm_pix`` must be an odd number of points since we ensure that zenith is
-    always sampled (i.e. l=0). We furthermore always put two points very close to
-    zenith (at 1e-18) to ensure that we can "interpolate away" from zenith properly.
-
-    Since we interpolate in real/imag, the phase flip at zenith will always mean that
-    there is a point with magnitude of zero between zenith and one of the points on the
-    circle closest to zenith. By making this circle very small (1e-18) we reduce the
-    chance that this artifact has any effect.
-    """
-    if not bm_pix % 2:
-        raise ValueError("Must use odd bm_pix so that you sample zenith!")
-
-    if bm_pix < 5:
-        raise ValueError("can't use bm_pix less than 5!")
-
-    lm = np.linspace(-1, 1, bm_pix - 2)
-
-    # The smallest value of lm should always be zero, however numerically it doesn't
-    # always quite work out, so we force it to be exactly zero.
-    lm[np.argmin(np.abs(lm))] = 0.0
-    lm = np.insert(
-        lm,
-        bm_pix // 2 - 1,
-        -1e-18,
-    )
-    lm = np.insert(lm, bm_pix // 2 + 1, 1e-18)
-
-    return lm
