@@ -143,6 +143,13 @@ def test_equatorial_to_enu():
         _az, _za = conversions.enu_to_az_za(vec_u[0], vec_u[1], orientation="uvbeam")
         assert np.isclose(_za, 0.0)
 
+        # Pointing South (UVBeam) (not 0-2pi)
+        _az, _za = conversions.enu_to_az_za(
+            vec_n[0], -vec_n[1], orientation="uvbeam", periodic_azimuth=False
+        )
+        assert np.isclose(_az, -0.5 * np.pi)
+        assert np.isclose(_za, 0.5 * np.pi)
+
         # Do inverse transform and check
         eq_e = np.dot(mat_enu_to_eci, vec_e)
         _tx, _ty, _tz = np.dot(mat_eci_to_enu, eq_e)
@@ -182,21 +189,3 @@ def test_equatorial_to_eci_coords():
         _ra, _dec = conversions.equatorial_to_eci_coords(
             ra, dec, obstime, (-30.7, 21.4, 1073.0), unit="rad", frame="icrs"
         )
-
-
-def test_bm_pix():
-    """Test the bm_pix_to_lm function."""
-    with pytest.raises(ValueError, match="can't use bm_pix less than 5!"):
-        conversions.bm_pix_to_lm(3)
-
-    with pytest.raises(
-        ValueError, match="Must use odd bm_pix so that you sample zenith!"
-    ):
-        conversions.bm_pix_to_lm(10)
-
-    for n in [101, 201, 153, 17]:
-        lm = conversions.bm_pix_to_lm(n)
-        assert 0.0 in lm.tolist()
-        assert np.all(np.diff(lm)) > 0.0
-        assert 1e-18 in lm.tolist()
-        assert -1e-18 in lm.tolist()
